<?php

namespace Drupal\acquia_contenthub_subscriber\EventSubscriber\PromoteEntityStatusTrack;

use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\TrackTotalsEvent;
use Drupal\acquia_contenthub_subscriber\SubscriberTracker;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class TrackTotals
 *
 * @package Drupal\acquia_contenthub_subscriber\EventSubscriber\PromoteEntityStatusTrack
 */
class TrackTotals implements EventSubscriberInterface {

  /**
   * Keep track of the tracker table.
   *
   * @var \Drupal\acquia_contenthub_subscriber\SubscriberTracker 
   */
  protected $tracker;

  /**
   * TrackTotals constructor.
   *
   * @param \Drupal\acquia_contenthub_subscriber\SubscriberTracker $tracker
   */
  public function __construct(SubscriberTracker $tracker) {
    $this->tracker = $tracker;
  }

  /**
   * Retrieve subscribed events.
   *
   * @return array
   */
  public static function getSubscribedEvents(): array {
    return [
      AcquiaContentHubEvents::PROMOTE_ENTITY_STATUS_TRACK_TOTALS => 'onPromoteEntityStatusTrackTotals'
    ];
  }

  /**
   * onPromoteEntityStatusTrackTotals event handler.
   *
   * @param \Drupal\acquia_contenthub\Event\TrackTotalsEvent $event
   */
  public function onPromoteEntityStatusTrackTotals(TrackTotalsEvent $event): void {
    $client = $event->getClient();
    $client_cdf = $client->getEntity($client->getSettings()->getUuid());

    $metadata = $client_cdf->getMetadata();
    $metadata['metrics'] = $this->tracker->getStatusMetrics();
    $client_cdf->setMetadata($metadata);

    $client->putEntities($client_cdf);
  }

}
